document.addEventListener('DOMContentLoaded', () => {
  const timeline = document.querySelector('.timeline');
  const textarea = document.querySelector('textarea');
  const chirpBtn = document.querySelector('.chirp-btn');

  // Sample data for initial posts
  const samplePosts = [
    {
      username: 'TechGuru',
      handle: '@techguru',
      content: 'Just launched my new website! #webdev #coding',
      timestamp: '2m',
      likes: 42,
      rechirps: 12,
    },
    {
      username: 'WebDev',
      handle: '@webdev',
      content: 'CSS Grid is amazing for layouts! 🎨',
      timestamp: '5m',
      likes: 89,
      rechirps: 24,
    }
  ];

  // Create post element
  const createPost = (post) => {
    const postElement = document.createElement('article');
    postElement.className = 'post';
    postElement.innerHTML = `
      <div class="post-header">
        <img src="data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='%23666'><circle cx='12' cy='12' r='12'/></svg>" alt="Avatar" class="avatar">
        <div class="post-info">
          <span class="username">${post.username}</span>
          <span class="handle">${post.handle}</span>
          <span class="timestamp">${post.timestamp}</span>
        </div>
      </div>
      <div class="post-content">${post.content}</div>
      <div class="post-actions">
        <button class="action-btn like-btn">
          <span class="likes-count">${post.likes}</span> Likes
        </button>
        <button class="action-btn rechirp-btn">
          <span class="rechirps-count">${post.rechirps}</span> Rechirps
        </button>
      </div>
    `;
    return postElement;
  };

  // Initialize timeline with sample posts
  samplePosts.forEach(post => {
    timeline.appendChild(createPost(post));
  });

  // Handle new chirp creation
  chirpBtn.addEventListener('click', () => {
    const content = textarea.value.trim();
    if (content) {
      const newPost = {
        username: 'You',
        handle: '@user',
        content,
        timestamp: 'now',
        likes: 0,
        rechirps: 0,
      };
      timeline.insertBefore(createPost(newPost), timeline.firstChild);
      textarea.value = '';
    }
  });

  // Character count
  textarea.addEventListener('input', () => {
    const remaining = 280 - textarea.value.length;
    chirpBtn.disabled = remaining < 0;
  });
});